<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'init', 'accounting_theme_options' );

/**
 * Build the custom settings & update OptionTree.
 */
function accounting_theme_options() {
  
  /* OptionTree is not loaded yet, or this is not an admin request */
  if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() )
    return false;
    
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( ot_settings_id(), array() );
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array( 
    'contextual_help' => array( 
      'sidebar'       => ''
    ),
    'sections'        => array( 
      array(
        'id'          => 'home_hero',
        'title'       => __( 'Home Hero', 'accounting' )
      ),
      array(
        'id'          => 'home_three_columns',
        'title'       => __( 'Three Columns', 'accounting' )
      )
    ),
    'settings'        => array( 
      array(
        'id'          => 'hero_title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => 'We help companies To Make',
        'type'        => 'text',
        'section'     => 'home_hero',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'hero_sub_title',
        'label'       => __( 'Sub-Title', 'accounting' ),
        'desc'        => '',
        'std'         => 'BETTER FINANCIAL DECISION',
        'type'        => 'text',
        'section'     => 'home_hero',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'background_image',
        'label'       => __( 'Background Image', 'accounting' ),
        'desc'        => '',
        'std'         => 'http://tallythemesdemo.com/wp3/accounting-pro/wp-content/uploads/sites/8/revslider/concept1/billionphotos-1676101.jpg',
        'type'        => 'upload',
        'section'     => 'home_hero',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns',
        'label'       => __( 'Three Columns', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_hero',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => 'What we Do',
        'type'        => 'text',
        'section'     => 'home_hero',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_1_tab',
        'label'       => __( '1st Column', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_1_title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_1_image',
        'label'       => __( 'Image', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_1_text',
        'label'       => __( 'Text', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_2_tab',
        'label'       => __( '2nd Column', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_2_title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_2_image',
        'label'       => __( 'Image', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_2_text',
        'label'       => __( 'Text', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_3_tab',
        'label'       => __( '3rd Column', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'tab',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_3_title',
        'label'       => __( 'Title', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'text',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_3_image',
        'label'       => __( 'Image', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
      array(
        'id'          => 'three_columns_3_text',
        'label'       => __( 'Text', 'accounting' ),
        'desc'        => '',
        'std'         => '',
        'type'        => 'textarea-simple',
        'section'     => 'home_three_columns',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      )
    )
  );
  
  /* allow settings to be filtered before saving */
  $custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( ot_settings_id(), $custom_settings ); 
  }
  
  /* Lets OptionTree know the UI Builder is being overridden */
  global $ot_has_custom_theme_options;
  $ot_has_custom_theme_options = true;
  
}